.. _spkg_entrypoints:

entrypoints: Discover and load entry points from installed Python packages
====================================================================================

Description
-----------

Discover and load entry points from installed packages.


Upstream Contact
----------------

https://github.com/takluyver/entrypoints


Special Update/Build Instructions
---------------------------------

Upstream does not provide a source tarball, so the tarball was taken
from github and renamed.

The source tarball does not contain setup.py, so we put the setup
commands in spkg-install.

Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_flit_core`

Version Information
-------------------

package-version.txt::

    0.4

version_requirements.txt::

    entrypoints >=0.3


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install entrypoints 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-entrypoints 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/entrypoints 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install py-entrypoints 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-entrypoints 



See https://repology.org/project/entrypoints/versions, https://repology.org/project/python:entrypoints/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

